import * as React from 'react';
import { Text, View, Image, } from 'react-native';
import RNBounceable from '@freakycoder/react-native-bounceable';
/**
 * ? Local Imports
 */
import styles, { _cardContainer, _checkboxContainer, _descriptionTextStyle, } from './CheckboxFlex.style';
import useStateWithCallback from './helper/useStateWithCallback';
const CheckboxFlex = ({ style, descriptionTextStyle, descriptionContainerStyle, date, description, checkboxContainerStyle, disableDate, dateTextStyle, dateContainerStyle, title, imageSource, titleNumberOfLines, titleTextStyle, iconImageStyle, titleContainerStyle, iconContainerStyle, disableBuiltInActiveSystemForCheckbox, disableBuiltInActiveSystemForCard, onCardPress, onPress, checkboxBorderColor = 'rgba(100,100,100,0.9)', activeCheckboxBackgroundColor = '#63eead', inactiveCheckboxBackgroundColor = 'transparent', activeCardBackgroundColor = '#2173FF', inactiveCardBackgroundColor = '#343c4d', }) => {
    const [isActive, setIsActive] = useStateWithCallback(false);
    const handlePress = () => {
        if (!disableBuiltInActiveSystemForCheckbox) {
            setIsActive(!isActive, (newValue) => {
                onPress?.(newValue);
            });
        }
        else {
            onPress?.();
        }
    };
    const handleCardPress = () => {
        if (!disableBuiltInActiveSystemForCard) {
            setIsActive(!isActive, (newValue) => {
                onCardPress?.(newValue);
            });
        }
        else {
            onCardPress?.();
        }
    };
    /* -------------------------------------------------------------------------- */
    /*                               Render Methods                               */
    /* -------------------------------------------------------------------------- */
    const renderIconContainer = () => (<View style={[styles.iconContainer, iconContainerStyle]}>
      <Image source={imageSource} style={[styles.iconImageStyle, iconImageStyle]}/>
    </View>);
    const renderTitle = () => (<View style={[styles.titleContainer, titleContainerStyle]}>
      <Text style={[styles.titleTextStyle, titleTextStyle]} numberOfLines={titleNumberOfLines || 2}>
        {title}
      </Text>
    </View>);
    const renderDate = () => !disableDate && (<View style={[styles.dateContainer, dateContainerStyle]}>
        <Text style={[styles.dateTextStyle, dateTextStyle]}>{date}</Text>
      </View>);
    const renderCheckbox = () => {
        return (<View style={[
                _checkboxContainer(isActive, checkboxBorderColor, activeCheckboxBackgroundColor, inactiveCheckboxBackgroundColor),
                checkboxContainerStyle,
            ]}>
        {isActive && (<Image style={styles.checkboxImageStyle} source={require('./check.png')}/>)}
      </View>);
    };
    const renderDescription = () => {
        if (!description) {
            return null;
        }
        else {
            return (<View style={[styles.descriptionContainer, descriptionContainerStyle]}>
          <Text numberOfLines={4} style={[_descriptionTextStyle(isActive), descriptionTextStyle]}>
            {description}
          </Text>
        </View>);
        }
    };
    const renderCard = () => {
        return (<View style={_cardContainer(isActive, activeCardBackgroundColor, inactiveCardBackgroundColor)}>
        <View style={styles.cardContainerGlue}>
          {renderIconContainer()}
          {renderTitle()}
          {renderDate()}
        </View>
        {renderDescription()}
      </View>);
    };
    return (<View style={[styles.container, style]}>
      <RNBounceable bounceEffectIn={0.93} onPress={handlePress}>
        {renderCheckbox()}
      </RNBounceable>
      <RNBounceable bounceEffectIn={0.93} onPress={handleCardPress}>
        {renderCard()}
      </RNBounceable>
    </View>);
};
export default CheckboxFlex;
//# sourceMappingURL=CheckboxFlex.js.map